@@ -47,7 +47,7 @@ from contextlib import contextmanager
 import msgpack
 import pylibmc
 
-VERSION = "0.8.5"
+VERSION = "0.8.7"
 RUN_PATH = "/run/starrydb/"
 SERVER_ADDRESS = f"{RUN_PATH}address"
 CACHE_SOCKET = f"{RUN_PATH}cache.sock"
@@ -257,6 +257,11 @@ class StarryServer(object):
                             if depot not in self.depots:
                                 self.depots[depot] = StarryDepot(depot, self.rw_ratio, self.cursor, self.memcached)
                                 self.cursor += 1
+
+                    try:
+                        conn.send((None, None))
+                    except:
+                        pass
                 else:
                     (ret, val) = (True, "")
 
@@ -1183,12 +1188,7 @@ class StarryClient(object):
             self.path = os.path.abspath(path)
 
         for _ in range(int(workers)):
-            client = multiprocessing.connection.Client(self.address, authkey=self.authkey)
-
-            if self.path is not None:
-                client.send(("open", self.path))
-
-            self.workers.put(client)
+            self.workers.put(multiprocessing.connection.Client(self.address, authkey=self.authkey))
 
     def __del__(self):
         try:
@@ -1230,18 +1230,19 @@ class StarryClient(object):
         try:
             if path is not None:
                 client.send(("open", os.path.abspath(path)))
-            elif thread_flag is True:
+            else:
                 client.send(("open", self.path))
 
+            (ret, _) = client.recv()
+            if ret is not None:
+                if client.poll(self.conn_timeout):
+                    (ret, _) = client.recv()
+
+                if ret is not None:
+                    raise StarryError("connect server failed.")
+
             yield self.Connection(client, self.conn_timeout)
         except Exception as e:
-            if thread_flag is False:
-                try:
-                    if client.poll(self.conn_timeout):
-                        client.recv()
-                except:
-                    pass
-
             raise StarryError(f"Caught exception: {e.__doc__}({e})")
         finally:
             if thread_flag is False:
